==> node-unique-array-0.0.4.tgz: package/readme.md <==
#node-unique-array




## Install

```sh
$ npm install node-unique-array --save
```


Then in code you can do:

```js
var unique_array = require('node-unique-array');
```



###Basic Example 1

```js

var nodeUnique = require('node-unique-array')

var unique_array = new nodeUnique();


//******* add Method *********

//we can add object to  addMethod

unique_array.add({name: 'vishnu', id: 100 });

//we can add ArrayOfObjects to  addMethod

unique_array.add([
                  {name: 'vishnu', id: 100 } ,
                  {name: 'raj', id: 101 }
                 ]);

// we can also add no.of ArrayOfObjects to addMethod

unique_array.add([
                  {name: 'vishnu', id: 100 } ,
                  {name: 'raj', id: 101 }
                 ],
                 [
                  {name: 'kumar', id: 111 } ,
                  {name: 'raj', id: 101 }
                 ]);

console.log(unique_array.get());

//======out put====

  [
   { name: 'vishnu', id: 100 },
   { name: 'raj', id: 101 },
   { name: 'kumar', id: 111 }
  ]





//******* remove Method *********

console.log(unique_array.remove({name: 'vishnu', id: 100 }));

//======out put====

  [
   { name: 'raj', id: 101 },
   { name: 'kumar', id: 111 }
  ]

//******* get Method *********

// get() method return unique array objects

console.log(unique_array.get());

//======out put====

  [
   { name: 'raj', id: 101 },
   { name: 'kumar', id: 111 }
  ]



//******* contains Method *********

console.log(unique_array.contains({ name: 'raj', id: 101 })) // returns true

//we can check arrayOfObjects contains Or not
//===>it returns true when all the objects in input array should contain in unique_array
//===>if one Object not contains in unique_array then it  returns false

console.log(unique_array.contains([ { name: 'raj', id: 101 } , { name: 'kumar', id: 111 }]));
// returns true

console.log(unique_array.contains([ { name: 'king', id: 100 } , { name: 'kumar', id: 111 }]));
// returns false




//******* size Method *********

//it returns length of the unique_array
console.log(unique_array.size());
//======out put======
//2



//******* clear Method *********

//it clear the unique_array array and makes empty

console.log(unique_array.clear();)
//======out put======
// []

```


###Basic Example 2

we can also pass input array while creating new instance array

```js

var nodeUnique = require('node-unique-array')

var unique_array = new nodeUnique([{name:'vishnu',id:100},{name:'vishnu',id:100}]);


console.log(unique_array.get());

//======out put======
 [{name:'vishnu',id:100}]
 
 ```

==> node-unique-array-0.0.5.tgz: package/readme.md <==
#node-unique-array




## Install

```sh
$ npm install node-unique-array --save
```


Then in code you can do:

```js
var nodeUnique = require('node-unique-array');
```



###Basic Example 1

```js

var nodeUnique = require('node-unique-array')

var unique_array = new nodeUnique();


//******* add Method *********

//we can add object to  addMethod

unique_array.add({name: 'vishnu', id: 100 });

//we can add ArrayOfObjects to  addMethod

unique_array.add([
                  {name: 'vishnu', id: 100 } ,
                  {name: 'raj', id: 101 }
                 ]);

// we can also add no.of ArrayOfObjects to addMethod

unique_array.add([
                  {name: 'vishnu', id: 100 } ,
                  {name: 'raj', id: 101 }
                 ],
                 [
                  {name: 'kumar', id: 111 } ,
                  {name: 'raj', id: 101 }
                 ]);

console.log(unique_array.get());

//======out put====

  [
   { name: 'vishnu', id: 100 },
   { name: 'raj', id: 101 },
   { name: 'kumar', id: 111 }
  ]





//******* remove Method *********

console.log(unique_array.remove({name: 'vishnu', id: 100 }));

//======out put====

  [
   { name: 'raj', id: 101 },
   { name: 'kumar', id: 111 }
  ]

//******* get Method *********

// get() method return unique array objects

console.log(unique_array.get());

//======out put====

  [
   { name: 'raj', id: 101 },
   { name: 'kumar', id: 111 }
  ]



//******* contains Method *********

console.log(unique_array.contains({ name: 'raj', id: 101 })) // returns true

//we can check arrayOfObjects contains Or not
//===>it returns true when all the objects in input array should contain in unique_array
//===>if one Object not contains in unique_array then it  returns false

console.log(unique_array.contains([
                                   { name: 'raj', id: 101 } ,
                                   { name: 'kumar', id: 111 }
                                  ]));
// returns true


console.log(unique_array.contains([
                                   { name: 'king', id: 100 } ,
                                   { name: 'kumar', id: 111 }
                                  ]));
// returns false




//******* size Method *********

//it returns length of the unique_array
console.log(unique_array.size());
//======out put======
//2



//******* clear Method *********

//it clear the unique_array array and makes empty

console.log(unique_array.clear();)
//======out put======
// []

```


###Basic Example 2

we can also pass input array while creating new instance

```js

var nodeUnique = require('node-unique-array')

var unique_array = new nodeUnique([
                                   {name:'vishnu',id:100},
                                   {name:'vishnu',id:100}
                                  ]);


console.log(unique_array.get());

//======out put======
 [{name:'vishnu',id:100}]
 
 ```
